@@ -8,11 +8,21 @@ from fabric.api import *
 from fabric.contrib import files
 from fabric import state
 from fabric import network
+from fabric import operations
 
 
-__all__ = ['run_as', 'update_env',
-           'inside_project', 'inside_virtualenv', 'inside_src',
-           'delete_pyc', 'print_env', 'detect_os']
+__all__ = ['run_as', 'update_env', 'inside_project', 'inside_virtualenv',
+           'inside_src', 'delete_pyc', 'print_env', 'detect_os']
+
+DETECTION_ERROR_MESSAGE = """
+OS detection failed. This probably means your OS is not
+supported by django-fab-deploy. If you really know what
+you are doing, set env.conf.OS variable to desired OS
+name in order to bypass this error message.
+If you believe the OS is supported but the detection
+fails or you want to get your OS supported, please fire an issue at
+https://bitbucket.org/kmike/django-fab-deploy/issues/new
+"""
 
 def _codename(distname, version, id):
     patterns = [
@@ -29,21 +39,16 @@ def detect_os():
         return env.conf['OS']
     output = run('python -c "import platform; print platform.dist()"')
     name = _codename(*eval(output))
+    if name is None:
+        abort(DETECTION_ERROR_MESSAGE)
+
     puts('%s detected' % name)
     return name
 
 def run_as(user):
     """
     Decorator. Runs fabric command as specified user. It is most useful to
-    run commands that require root access to server::
-
-        from fabric.api import run
-        from fab_deploy.utils import run_as
-
-        @run_as('root')
-        def aptitude_update():
-            run('aptitude update')
-
+    run commands that require root access to server.
     """
     def decorator(func):
         @wraps(func)
@@ -56,14 +61,36 @@ def run_as(user):
         return inner
     return decorator
 
+def run_as_sudo(func):
+    """
+    Decorator. By default all commands are executed as user without
+    sudo access for security reasons. Use this decorator to run fabric
+    command as user with sudo access (:attr:`env.conf.SUDO_USER`)::
+
+        from fabric.api import run
+        from fab_deploy import utils
+
+        @utils.run_as_sudo
+        def aptitude_update():
+            run('aptitude update')
+    """
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        return run_as(env.conf.SUDO_USER)(func)(*args, **kwargs)
+    return wrapper
+
 def upload_config_template(name, to=None, skip_unexistent=False, **kwargs):
     if to is None:
         base_dir = env.conf['ENV_DIR'] + "/etc/"
         run('mkdir -p ' + base_dir)
         to = base_dir + name
     config_template = _config_template_path(name)
-    if config_template is None and skip_unexistent:
-        return
+
+    if config_template is None:
+        if skip_unexistent:
+            return
+        operations._handle_failure('Config template "%s" is not found' % name)
+
     files.upload_template(config_template, to, env.conf, use_jinja=True,
                           **kwargs)
 
@@ -86,22 +113,24 @@ def update_env():
             )
             update_env()
     """
-    assert len(env.hosts)==1, "Multiple hosts in env.hosts are not supported now. (%s)" % env.hosts
+    assert len(env.hosts) == 1, "Multiple hosts in env.hosts are not supported now. (%s)" % env.hosts
     user, host, port = network.normalize(env.hosts[0])
 
     env.conf = getattr(env, 'conf', {})
+
     env.conf.setdefault('INSTANCE_NAME', user)
     env.conf.setdefault('PROJECT_PATH', '')
 
-    HOME_DIR = '/home/%s' % user
+    HOME_DIR = '/home/%s' % user if user != 'root' else '/root'
     SRC_DIR = posixpath.join(HOME_DIR, 'src', env.conf['INSTANCE_NAME'])
     PROJECT_DIR = posixpath.join(SRC_DIR, env.conf['PROJECT_PATH']).rstrip('/')
 
     defaults = state._AttributeDict(
         HG_BRANCH='default',
-        GIT_BRANCH = 'master',
+        GIT_BRANCH='master',
         DB_NAME=env.conf['INSTANCE_NAME'],
         DB_USER='root',
+        SUDO_USER='root',
         PROCESSES=1,
         THREADS=15,
         SERVER_NAME=host,
@@ -115,19 +144,30 @@ def update_env():
 
         PIP_REQUIREMENTS_PATH='reqs',
         PIP_REQUIREMENTS='all.txt',
-        PIP_REQUIREMENTS_ACTIVE = 'active.txt',
+        PIP_REQUIREMENTS_ACTIVE='active.txt',
 
         # these options shouldn't be set by user
         HOME_DIR=HOME_DIR,
         ENV_DIR=posixpath.join(HOME_DIR, 'envs', env.conf['INSTANCE_NAME']),
         SRC_DIR=SRC_DIR,
-        PROJECT_DIR = PROJECT_DIR,
+        PROJECT_DIR=PROJECT_DIR,
         USER=user,
     )
     defaults.update(env.conf)
 
     env.conf = defaults
 
+    if env.conf.DB_USER == 'root':
+        if 'DB_ROOT_PASSWORD' in env.conf and 'DB_PASSWORD' in env.conf:
+            msg = "DB_ROOT_PASSWORD and DB_PASSWORD must be the same because DB_USER is root"
+            assert env.conf.DB_ROOT_PASSWORD == env.conf.DB_PASSWORD, msg
+        else:
+            # auto-fill the missing option
+            password = env.conf.get('DB_ROOT_PASSWORD',
+                                    env.conf.get('DB_PASSWORD', None))
+            if password is not None:
+                env.conf.DB_PASSWORD = env.conf.DB_ROOT_PASSWORD = password
+
     for vcs in ['git', 'hg', 'none']: # expand VCS name to full import path
         if env.conf.VCS == vcs:
             env.conf.VCS = 'fab_deploy.vcs.' + vcs
@@ -135,7 +175,7 @@ def update_env():
 
 def virtualenv():
     """
-    Context manager. Use it for perform actions inside virtualenv::
+    Context manager. Use it for perform actions with virtualenv activated::
 
         with virtualenv():
             # virtualenv is active here
@@ -145,7 +185,7 @@ def virtualenv():
 
 def inside_virtualenv(func):
     """
-    Decorator. Use it for perform actions inside virtualenv::
+    Decorator. Use it for perform actions with virtualenv activated::
 
         @inside_virtualenv
         def my_command():
