@@ -13,4 +13,5 @@ def push():
     local('hg push ssh://%s/src/%s/' % (env.hosts[0], env.conf.INSTANCE_NAME))
 
 def configure():
-    upload_config_template('hgrc', env.conf['SRC_DIR'] + '/.hg/hgrc')
+    upload_config_template('hgrc', env.conf.SRC_DIR + '/.hg/hgrc',
+                           skip_unexistent=True)
