@@ -30,21 +30,25 @@ if __name__ == '__main__':
         sys.exit(1)
 
     atexit.register(beep)
-
     FabDeployTest.vm_name = sys.argv[1]
-    common_tests = load([BasicTest, SshTest, MysqlTest, CrontabTest])
-    fast_tests = load([FastPrepareServerTest, ApacheSetupTest,
-                       PipSetupTest, NoPipSetupTest])
+
+    common = [SshTest, MysqlTest, MysqlNonRootTest, BasicTest]
+
     suites = {
-        'fast': TestSuite(common_tests + fast_tests),
-        'slow': TestSuite(load([DeployTest, CustomLayoutDeployTest])),
-        'prepare': TestSuite(common_tests + load([PrepareServerTest])),
+        'misc': TestSuite(load(common + [
+                    FastPrepareServerTest, ApacheSetupTest,
+                    PipSetupTest, NoPipSetupTest, CrontabTest
+                ])),
+        'deploy': TestSuite(load([
+                    DeployTest, CustomLayoutDeployTest
+                ])),
+        'prepare': TestSuite(load(common + [PrepareServerTest])),
     }
-    suites['all'] = TestSuite([suites['fast'], suites['slow']])
+    suites['all'] = TestSuite([suites['misc'], suites['deploy']])
 
     suite_name = sys.argv[2]
     if suite_name in suites:
-        unittest.TextTestRunner().run(suites[suite_name])
+        unittest.TextTestRunner(verbosity=2).run(suites[suite_name])
     else:
         sys.argv = [sys.argv[0]] + sys.argv[2:]
         unittest.main()
