@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 from fabric.api import *
+from fabric.state import _AttributeDict
 from fabtest import FabTest
 from fab_deploy.utils import update_env
 from fab_deploy_tests.utils import get_package_state, private_key_path
@@ -14,7 +15,7 @@ class FabDeployTest(FabTest):
         update_env()
 
     def setup_conf(self):
-        env.conf = getattr(env, 'conf', {})
+        env.conf = _AttributeDict()
 
     def assertPackageInstalled(self, name):
         self.assertEqual(get_package_state(name), 'i')
